==> savane-1.0.0.tar.gz: savane/frontend/php/project/memberlist.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: memberlist.php,v 1.17 2004/01/31 00:56:19 yeupou Exp $
//
//
// Copyright 1999-2000 (c) The SourceForge Crew
//
//
//  Copyright 2000-2003 (c) Free Software Foundation,
//                          Mathieu Roy <yeupou@gnu.org>,
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//
//

//

require "../include/pre.php";
require_directory("trackers");

if ((!$group_id) && $form_grp) 
     $group_id=$form_grp;
     
     site_project_header(array('title'=>_("Project Member List"),
			       'group'=>$group_id,
			       'toptab'=>'memberlist'));


     /* permit to the user to specify something */

     print '<form action="'. $PHP_SELF .'" method="get">';
     print '<input type="hidden" name="group" value="'.$group_name.'">';
     print '<h3>';
     if ($detailed)
{ $checked = " selected"; }
printf (_("Browse with the %s memberlist."), '<select name="detailed"><option value="0">'._("Basic").'</option><option value="1"'.$checked.'>'._("Detailed").'</option></select>');
print '&nbsp;&nbsp;&nbsp;&nbsp;<input type="submit" value="'._("Apply").'"></h3></form>';

print '<br>';


if (!member_check(0,$group_id))
{
  printf(_("If you would like to contribute to this project by becoming a member, %s, designated in bold text below."),
	 '<a href="'.$GLOBALS['sys_home'].'account/change_groups.php?words='.group_getname($group_id).'#searchgroup">'._("contact one of the project admins")."</a>"); 
  print '<br><br>';
} 
else
{
  print _("Note that you can 'watch' a member of your project. It allows you, for instance, to be the backup of someone when he's away from the office, to do the QA to all of his activities on this project: you will receive a copy of his mail notifications related to this project.");
  print '<br><br>';

}

if ($detailed)
{ 
  member_explain_roles(); 
  // FIXME: yeupou@gnu.org 2003-11-07
  // The best would be to print non-specific roles but roles in any case.
  // It requires more, so we will see if there are people interested in that
  // or not.
  print '<p>'._("On this page are only presented specific roles, roles which are not attributed by default when joining this project.").'</p>';
}

// list members
if (!$detailed)
{
  $sql =  "SELECT user.user_name AS user_name, "
     . "user.user_id AS user_id,"
     . "user.realname AS realname, "
     . "user.add_date AS add_date, "
     . "user.people_view_skills AS people_view_skills, "
     . "user_group.admin_flags AS admin_flags, "
     . "user.email AS email "
     . "FROM user,user_group "
     . "WHERE user.user_id=user_group.user_id AND user_group.group_id=$group_id  AND user_group.admin_flags <> 'P' "
     . "ORDER BY user.user_name";
}
else
{
  $sql =  "SELECT user.user_name AS user_name, "
     . "user.user_id AS user_id,"
     . "user.realname AS realname, "
     . "user.add_date AS add_date, "
     . "user.people_view_skills AS people_view_skills, "
     . "user_group.admin_flags AS admin_flags, "
     . "user_group.bugs_flags AS bugs_flags, "
     . "user_group.task_flags AS task_flags, "
     . "user_group.patch_flags AS patch_flags, "
     . "user_group.news_flags AS news_flags, "
     . "user_group.support_flags AS support_flags, "
     . "user.email AS email "
     . "FROM user,user_group "
     . "WHERE user.user_id=user_group.user_id AND user_group.group_id=$group_id  AND user_group.admin_flags <> 'P' "
     . "ORDER BY user.user_name";  
}


$title_arr=array();
$title_arr[]=_("Name");
$title_arr[]=_("Login");
if ($detailed)
{ $title_arr[]=_("Specific Role"); }
$title_arr[]=_("Email");
$title_arr[]=_("Skills");
if (user_ismember($group_id))
{
  $title_arr[]=_("Watch");
}

echo html_build_list_table_top ($title_arr);

$res_memb = db_query($sql);



function specific_print_role ($row, $title)
{		      
  print 
    (($row == 1)?$title._(" technician").',<br>':"").
    (($row == 3)?$title._(" manager").',<br>':"").
    (($row == 2)?$title._(" techn. & manager").',<br>':""); 
}

$i = 1;
while ($row_memb=db_fetch_array($res_memb)) 
{
  if ($row_memb[admin_flags] != 'P') 
    {
      $i++;
      print "\t<tr class=\"".utils_get_alt_row_color($i)."\">\n";
      print "\t\t";
      
      // Realname
      if ($row_memb[admin_flags] == 'A') {
	print "\t\t<td><b><a href=\"".$GLOBALS['sys_home']."users/$row_memb[user_name]/\">$row_memb[realname]</a></b></td>\n";
      } 
      else 
	{
	  print "\t\t<td>$row_memb[realname]</td>\n";
	}
      
      // Login
      print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."users/$row_memb[user_name]/\">$row_memb[user_name]</a></td>\n";
      
      // Role
      if ($detailed)
	{ 
	  print "\t\t<td align=\"middle\">";
	  if ($row_memb[admin_flags] == 'A') 
	    {
	      // No details if it is an admin
	      print _("project admin");
	    }
	  else
	    { 
	      // Print only not by default role.

	      specific_print_role($row_memb[support_flags], _("support tracker"));
	      specific_print_role($row_memb[bugs_flags], _("bug tracker"));
	      specific_print_role($row_memb[task_flags], _("task tracker"));
	      specific_print_role($row_memb[patch_flags], _("patch tracker"));
	      specific_print_role($row_memb[news_flags], _("news tracker"));

	    }
	  print "</td>\n";
	}
      
      // Email
      print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."sendmessage.php?touser=".$row_memb['user_id'].
	"\">".utils_antispam_email($row_memb['email'])."</td>\n";
    
      // Skills
      if ($row_memb['people_view_skills'] == 1) 
	{
	  print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."people/viewprofile.php?user_id=".$row_memb['user_id']."\">"._("View Skills")."</a></td>\n";
	} 
      else 
	{
	  print "\t\t<td align=\"middle\">"._("Set to private")."</td>\n"; 
	}
      // Watch
      if (user_ismember($group_id))
	{
	  $thisuser = user_getid();
	  if ($row_memb['user_id'] != $thisuser && !trackers_data_is_watched($thisuser,$row_memb['user_id'],$group_id))
	    {
	      // permit to add a watchee only if not already in the watched list
	      print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."my/?func=addwatchee&amp;group_id=$group_id&amp;watchee_id=".$row_memb['user_id']."\">"._("Watch Him")."</a></td>\n"; 
	    }
	  else 
	    {
	      print "\t\t<td align=\"middle\">---</td>\n"; 
	    }
	}
      print "\t<tr>\n";
    }
}
print "\t</table>";

site_project_footer(array());

?>

==> savane-1.0.1.tar.gz: savane/frontend/php/project/memberlist.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: memberlist.php,v 1.19 2004/03/02 18:26:18 toddy Exp $
//
//
// Copyright 1999-2000 (c) The SourceForge Crew
//
//
//  Copyright 2000-2003 (c) Free Software Foundation,
//                          Mathieu Roy <yeupou@gnu.org>,
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//
//

//

require "../include/pre.php";
require_directory("trackers");

if ((!$group_id) && $form_grp)
     $group_id=$form_grp;

     site_project_header(array('title'=>_("Project Memberlist"),
			       'group'=>$group_id,
			       'toptab'=>'memberlist'));


     /* permit to the user to specify something */

     print '<form action="'. $PHP_SELF .'" method="get">';
     print '<input type="hidden" name="group" value="'.$group_name.'">';
     print '<h3>';
     if ($detailed)
{ $checked = " selected"; }
printf (_("Browse with the %s memberlist."), '<select name="detailed"><option value="0">'._("Basic").'</option><option value="1"'.$checked.'>'._("Detailed").'</option></select>');
print '&nbsp;&nbsp;&nbsp;&nbsp;<input type="submit" value="'._("Apply").'"></h3></form>';

print '<br>';


if (!member_check(0,$group_id))
{
  printf(_("If you would like to contribute to this project by becoming a member, %s, designated in bold text below."),
	 '<a href="'.$GLOBALS['sys_home'].'account/change_groups.php?words='.group_getname($group_id).'#searchgroup">'._("contact one of the project admins")."</a>");
  print '<br><br>';
}
else
{
  print _("Note that you can 'watch' a member of your project. It allows you, for instance, to be the backup of someone when he's away from the office, to do the QA to all of his activities on this project: you will receive a copy of his mail notifications related to this project.");
  print '<br><br>';

}

if ($detailed)
{
  member_explain_roles();
  // FIXME: yeupou@gnu.org 2003-11-07
  // The best would be to print non-specific roles but roles in any case.
  // It requires more, so we will see if there are people interested in that
  // or not.
  print '<p>'._("On this page are only presented specific roles, roles which are not attributed by default when joining this project.").'</p>';
}

// list members
if (!$detailed)
{
  $sql =  "SELECT user.user_name AS user_name, "
     . "user.user_id AS user_id,"
     . "user.realname AS realname, "
     . "user.add_date AS add_date, "
     . "user.people_view_skills AS people_view_skills, "
     . "user_group.admin_flags AS admin_flags, "
     . "user.email AS email "
     . "FROM user,user_group "
     . "WHERE user.user_id=user_group.user_id AND user_group.group_id=$group_id  AND user_group.admin_flags <> 'P' "
     . "ORDER BY user.user_name";
}
else
{
  $sql =  "SELECT user.user_name AS user_name, "
     . "user.user_id AS user_id,"
     . "user.realname AS realname, "
     . "user.add_date AS add_date, "
     . "user.people_view_skills AS people_view_skills, "
     . "user_group.admin_flags AS admin_flags, "
     . "user_group.bugs_flags AS bugs_flags, "
     . "user_group.task_flags AS task_flags, "
     . "user_group.patch_flags AS patch_flags, "
     . "user_group.news_flags AS news_flags, "
     . "user_group.support_flags AS support_flags, "
     . "user.email AS email "
     . "FROM user,user_group "
     . "WHERE user.user_id=user_group.user_id AND user_group.group_id=$group_id  AND user_group.admin_flags <> 'P' "
     . "ORDER BY user.user_name";
}


$title_arr=array();
$title_arr[]=_("Name");
$title_arr[]=_("Login");
if ($detailed)
{ $title_arr[]=_("Specific Role"); }
$title_arr[]=_("Email");
$title_arr[]=_("Skills");
if (user_ismember($group_id))
{
  $title_arr[]=_("Watch");
}

echo html_build_list_table_top ($title_arr);

$res_memb = db_query($sql);



function specific_print_role ($row, $title)
{
  print
    (($row == 1)?$title.' '._("technician").',<br>':"").
    (($row == 3)?$title.' '._("manager").',<br>':"").
    (($row == 2)?$title.' '._("techn. & manager").',<br>':"");
}

$i = 1;
while ($row_memb=db_fetch_array($res_memb))
{
  if ($row_memb[admin_flags] != 'P')
    {
      $i++;
      print "\t<tr class=\"".utils_get_alt_row_color($i)."\">\n";
      print "\t\t";

      // Realname
      if ($row_memb[admin_flags] == 'A') {
	print "\t\t<td><b><a href=\"".$GLOBALS['sys_home']."users/$row_memb[user_name]/\">$row_memb[realname]</a></b></td>\n";
      }
      else
	{
	  print "\t\t<td>$row_memb[realname]</td>\n";
	}

      // Login
      print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."users/$row_memb[user_name]/\">$row_memb[user_name]</a></td>\n";

      // Role
      if ($detailed)
	{
	  print "\t\t<td align=\"middle\">";
	  if ($row_memb[admin_flags] == 'A')
	    {
	      // No details if it is an admin
	      print _("project admin");
	    }
	  else
	    {
	      // Print only not by default role.

	      specific_print_role($row_memb[support_flags], _("support tracker"));
	      specific_print_role($row_memb[bugs_flags], _("bug tracker"));
	      specific_print_role($row_memb[task_flags], _("task tracker"));
	      specific_print_role($row_memb[patch_flags], _("patch tracker"));
	      specific_print_role($row_memb[news_flags], _("news tracker"));

	    }
	  print "</td>\n";
	}

      // Email
      print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."sendmessage.php?touser=".$row_memb['user_id'].
	"\">".utils_antispam_email($row_memb['email'])."</td>\n";

      // Skills
      if ($row_memb['people_view_skills'] == 1)
	{
	  print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."people/viewprofile.php?user_id=".$row_memb['user_id']."\">"._("View Skills")."</a></td>\n";
	}
      else
	{
	  print "\t\t<td align=\"middle\">"._("Set to private")."</td>\n";
	}
      // Watch
      if (user_ismember($group_id))
	{
	  $thisuser = user_getid();
	  if ($row_memb['user_id'] != $thisuser && !trackers_data_is_watched($thisuser,$row_memb['user_id'],$group_id))
	    {
	      // permit to add a watchee only if not already in the watched list
	      print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."my/?func=addwatchee&amp;group_id=$group_id&amp;watchee_id=".$row_memb['user_id']."\">"._("Watch Him")."</a></td>\n";
	    }
	  else
	    {
	      print "\t\t<td align=\"middle\">---</td>\n";
	    }
	}
      print "\t<tr>\n";
    }
}
print "\t</table>";

site_project_footer(array());

?>
